@@ -1,3 +1,25 @@
+# This module, and all included code, is made available under the terms of the MIT
+# Licence
+#
+# Copyright 2022 (c) Erik de Lange, Copyright (c) 2022-2023 David Love
+#
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal in
+# the Software without restriction, including without limitation the rights to
+# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
+# the Software, and to permit persons to whom the Software is furnished to do so,
+# subject to the following conditions:
+#
+# The above copyright notice and this permission notice shall be included in all
+# copies or substantial portions of the Software.
+#
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
+# FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
+# COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
+# IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
 """
 Formats a basic HTTP/1.1 response. The actual body of the response is largely
 determined by the callers API layer: `urest.http.response.HTTPResponse` is a
@@ -11,31 +33,6 @@ Standards
 
   * For HTTP/1.1 specification see: https://www.ietf.org/rfc/rfc2616.txt
   * For MIME types see: https://www.iana.org/assignments/media-types/media-types.xhtml
-
-Licence
--------
-
-This module, and all included code, is made available under the terms of the MIT
-Licence
-
-> Copyright 2022 (c) Erik de Lange, Copyright (c) 2022-2023 David Love
-
-> Permission is hereby granted, free of charge, to any person obtaining a copy
-of this software and associated documentation files (the "Software"), to deal in
-the Software without restriction, including without limitation the rights to
-use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
-the Software, and to permit persons to whom the Software is furnished to do so,
-subject to the following conditions:
-
-> The above copyright notice and this permission notice shall be included in all
-copies or substantial portions of the Software.
-
-> THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
-FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
-COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
-IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
-CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 """
 
 # Import the Asynchronous IO Library, preferring the MicroPython library if
@@ -57,7 +54,6 @@ HTTPStatus = {"OK", "NOT_OK", "NOT_FOUND"}
 
 
 class HTTPResponse:
-
     ##
     ## Constructor
     ##
@@ -197,8 +193,8 @@ class HTTPResponse:
 
         `async`
 
-          The return type is complex, and indicates this method is expected to be run
-          as a co-routine under the `asyncio` library.
+            The return type is complex, and indicates this method is expected to be run
+            as a co-routine under the `asyncio` library.
         """
 
         # **NOTE**: This implementation should be in "match/case", but MicroPython
