@@ -1,3 +1,25 @@
+# This module, and all included code, is made available under the terms of the MIT
+# Licence
+#
+# Copyright 2022 (c) Erik de Lange, Copyright (c) 2022-2023 David Love
+#
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal in
+# the Software without restriction, including without limitation the rights to
+# use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
+# the Software, and to permit persons to whom the Software is furnished to do so,
+# subject to the following conditions:
+#
+# The above copyright notice and this permission notice shall be included in all
+# copies or substantial portions of the Software.
+#
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
+# FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
+# COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
+# IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
+# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
 """
 Micro HTTP server dedicated to REST-style API Requests. Inspired by the
 [MicroPython HTTP Server](https://github.com/erikdelange/MicroPython-HTTP-Server)
@@ -14,31 +36,6 @@ Standards
 
   * For the HTTP/1.1 specification see: https://www.ietf.org/rfc/rfc2616.txt
   * For the JSON specification see: https://www.ecma-international.org/publications-and-standards/standards/ecma-404
-
-Licence
--------
-
-This module, and all included code, is made available under the terms of the MIT
-Licence
-
-> Copyright 2022 (c) Erik de Lange, Copyright (c) 2022-2023 David Love
-
-> Permission is hereby granted, free of charge, to any person obtaining a copy
-of this software and associated documentation files (the "Software"), to deal in
-the Software without restriction, including without limitation the rights to
-use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
-the Software, and to permit persons to whom the Software is furnished to do so,
-subject to the following conditions:
-
-> The above copyright notice and this permission notice shall be included in all
-copies or substantial portions of the Software.
-
-> THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
-FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
-COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
-IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
-CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 """
 
 # Import the standard error library
@@ -81,10 +78,29 @@ JSON_TYPE_ERROR = 1
 
 
 class RESTServerError(Exception):
+    """
+    Internal Server Error. Thrown as a general failure of the
+    `urest.http.server` module when no more specific exception is available. This
+    usually indicates a bug in the library.
+
+    This exception should be notified to the client as the HTTP response '`500
+    Internal Server Error`', and further processing should not be attempted.
+    """
+
     pass
 
 
 class RESTParseError(Exception):
+    """
+    Parse failure. The HTTP header or body elements supplied by the network
+    client are invalid, and cannot be parsed correctly by the `urest.http.server`
+    module.
+
+    This exception should be notified to the client as the HTTP response '`400
+    Bad Request`', and further processing should not be attempted until the client
+    retries the request.
+    """
+
     pass
 
 
@@ -94,7 +110,6 @@ class RESTParseError(Exception):
 
 
 class RESTServer:
-
     #
     def __init__(
         self,
@@ -225,13 +240,18 @@ class RESTServer:
         data_str: str
             A JSON object string, representing a single dictionary
 
+        Raises
+        ------
+
+        RESTParseError
+
         Returns
         -------
 
         dict
-          A mapping of (key, value) pairs which defines the dictionary of the `data_str`
-          object. All `key` values will be in Python string format: values will be as
-          defined in the `data_str` object.
+            A mapping of (key, value) pairs which defines the dictionary of the `data_str`
+            object. All `key` values will be in Python string format: values will be as
+            defined in the `data_str` object.
         """
 
         return_dictionary = {}
@@ -245,7 +265,6 @@ class RESTServer:
         token_str = ""
 
         for char in data_str.decode("ascii"):
-
             # Look for the first object
             if char in ["{"]:
                 object_start = True
@@ -253,10 +272,8 @@ class RESTServer:
             # If we are inside an object, attempt to assemble the
             # tokens
             if object_start:
-
                 # If a '"' is found...
                 if char in ['"']:
-
                     # ... and if we are building a token, this should be the
                     # end of a string, so push it to the stack ...
                     if token_start:
@@ -285,11 +302,9 @@ class RESTServer:
 
                 # Look for the end of a token
                 if char in [",", "}"]:
-
                     # Add the key/value to the return dictionary if
                     # it appears to be valid
                     if token_sep:
-
                         if token_type == JSON_TYPE_INT:
                             # The token won't have been terminated
                             # so still should be in `token_str`
@@ -343,7 +358,6 @@ class RESTServer:
         old_handler = None
 
         try:
-
             if noun in self._nouns:
                 old_handler = self._nouns[noun]
 
@@ -394,7 +408,6 @@ class RESTServer:
         # fragments into an API request. Any failures should result in an
         # `Exception`: success should result in an API call
         try:
-
             # Get the raw network request and decode into UTF-8
             request_uri = await asyncio.wait_for(reader.readline(), self.read_timeout)
             request_uri = request_uri.decode("utf8")
@@ -404,14 +417,16 @@ class RESTServer:
                 # DEBUG
                 if __debug__:
                     print(
-                        f"CLIENT: [{writer.get_extra_info('peername')[0]}] Empty request line"
+                        f"CLIENT: [{writer.get_extra_info('peername')[0]}] Empty"
+                        " request line"
                     )
                     return
 
             # DEBUG
             if __debug__:
                 print(
-                    f"CLIENT URI : [{writer.get_extra_info('peername')[0]}] {request_uri.strip()}"
+                    f"CLIENT URI : [{writer.get_extra_info('peername')[0]}]"
+                    f" {request_uri.strip()}"
                 )
 
             # Get the header of the request, if it is available, decoded into UTF-8
@@ -432,7 +447,8 @@ class RESTServer:
             # DEBUG
             if __debug__:
                 print(
-                    f"CLIENT HEAD: [{writer.get_extra_info('peername')[0]}] {request_header}"
+                    f"CLIENT HEAD: [{writer.get_extra_info('peername')[0]}]"
+                    f" {request_header}"
                 )
 
             # Check if there is a body to follow the header ...
@@ -443,7 +459,6 @@ class RESTServer:
 
                 # ... check if there is _really a body to follow ...
                 if request_length > 0:
-
                     # ... if so, get the rest of the body of the request, decoded into UTF-8
 
                     try:
@@ -457,17 +472,21 @@ class RESTServer:
                         if __debug__:
                             print(f"!EXCEPTION!: {e}")
                             print(
-                                f"!INVALID DATA!: [{writer.get_extra_info('peername')[0]}] {request_data}"
+                                "!INVALID DATA!:"
+                                f" [{writer.get_extra_info('peername')[0]}]"
+                                f" {request_data}"
                             )
                         request_body = {}
 
                 # DEBUG
                 if __debug__:
                     print(
-                        f"CLIENT DATA: [{writer.get_extra_info('peername')[0]}] {request_data}"
+                        f"CLIENT DATA: [{writer.get_extra_info('peername')[0]}]"
+                        f" {request_data}"
                     )
                     print(
-                        f"CLIENT BODY: [{writer.get_extra_info('peername')[0]}] {request_body}"
+                        f"CLIENT BODY: [{writer.get_extra_info('peername')[0]}]"
+                        f" {request_body}"
                     )
 
             else:
